@@ -12,7 +12,7 @@ import simplejson
 
 from base64 import b64encode
 
-from fixtures import muchdata, reset_textstore, teststore
+from fixtures import muchdata, reset_textstore, _teststore
 from tiddlyweb.model.user import User
 from tiddlyweb.config import config
 
@@ -23,8 +23,8 @@ def setup_module(module):
         return serve.load_app()
     httplib2_intercept.install()
     wsgi_intercept.add_wsgi_intercept('our_test_domain', 8001, app_fn)
-    module.store = teststore()
     reset_textstore()
+    module.store = _teststore()
     muchdata(module.store)
 
     user = User('cdent')
