@@ -74,17 +74,14 @@ def put(environ, start_response):
 def _check_bag_constraint(environ, bag, constraint):
     """
     Check to see if the bag allows the current user
-    to perform the requested action.
+    to perform the requested action. Lets NoBagError
+    raise.
     """
     store = environ['tiddlyweb.store']
     usersign = environ['tiddlyweb.usersign']
-    try:
-        bag.skinny = True
-        bag = store.get(bag)
-        bag.policy.allows(usersign, constraint)
-    except NoBagError, exc:
-        raise HTTP404('bag %s not found while checking policy, %s' %
-                (bag.name, exc))
+    bag.skinny = True
+    bag = store.get(bag)
+    bag.policy.allows(usersign, constraint)
 
 
 def _delete_tiddler(environ, start_response, tiddler):
@@ -320,7 +317,7 @@ def _validate_tiddler(environ, tiddler):
         if incoming_etag and incoming_etag != tiddler_etag:
             raise HTTP412('Provided ETag does not match. '
                 'Server content probably newer.')
-    etag = ('Etag', tiddler_etag)
+    etag = ('Etag', '%s' % tiddler_etag)
     return last_modified, etag
 
 
@@ -403,7 +400,7 @@ def _tiddler_etag(tiddler):
     Calculate the ETAG of a tiddler, based on
     bag name, tiddler title and revision.
     """
-    return str('%s/%s/%s' %
+    return str('"%s/%s/%s"' %
             (urllib.quote(tiddler.bag.encode('utf-8'), safe=''),
                 urllib.quote(tiddler.title.encode('utf-8'), safe=''),
                 tiddler.revision))
